==> MoinLight-0.1.tar.bz2: MoinLight-0.1/moinformat/serialisers/moin/table.py <==
#!/usr/bin/env python

"""
Moin wiki table serialiser.

Copyright (C) 2017, 2018 Paul Boddie <paul@boddie.org.uk>

This program is free software; you can redistribute it and/or modify it under
the terms of the GNU General Public License as published by the Free Software
Foundation; either version 3 of the License, or (at your option) any later
version.

This program is distributed in the hope that it will be useful, but WITHOUT
ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
details.

You should have received a copy of the GNU General Public License along with
this program.  If not, see <http://www.gnu.org/licenses/>.
"""

from moinformat.serialisers.moin.moin import MoinSerialiser

class MoinTableSerialiser(MoinSerialiser):

    "Serialisation of the page."

    def init(self):
        self.first_cell = False
        self.first_row = False

    def start_table(self):
        self.first_row = True

    def start_table_cell(self, attrs):
        if not self.first_cell:
            self.out("||")
        else:
            self.first_cell = False

    def start_table_row(self):
        self.first_cell = True
        if not self.first_row:
            self.out("==")
        else:
            self.first_row = False

    def end_table_row(self, trailing):
        self.out(trailing)

    def continuation(self, text):
        self.out(text)

serialiser = MoinTableSerialiser

# vim: tabstop=4 expandtab shiftwidth=4

==> MoinLight-0.2.1.tar.bz2: MoinLight-0.2.1/moinformat/serialisers/moin/table.py <==
#!/usr/bin/env python

"""
Moin wiki table serialiser.

Copyright (C) 2017, 2018, 2021 Paul Boddie <paul@boddie.org.uk>

This program is free software; you can redistribute it and/or modify it under
the terms of the GNU General Public License as published by the Free Software
Foundation; either version 3 of the License, or (at your option) any later
version.

This program is distributed in the hope that it will be useful, but WITHOUT
ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
details.

You should have received a copy of the GNU General Public License along with
this program.  If not, see <http://www.gnu.org/licenses/>.
"""

from moinformat.serialisers.moin.moin import MoinSerialiser

class MoinTableSerialiser(MoinSerialiser):

    "Serialisation of the page."

    input_formats = ["table"]

    def init(self):
        self.first_cell = False
        self.first_row = False

    def start_table(self):
        self.first_row = True

    def start_table_cell(self, attrs, leading, padding):
        if not self.first_cell:
            self.out(leading)
            self.out("||")
        else:
            self.first_cell = False
        self.out(padding)

    def start_table_row(self, leading, padding):
        self.first_cell = True
        if not self.first_row:
            self.out(leading)
            self.out("==")
            self.out(padding)
        else:
            self.first_row = False

    def end_table_row(self, trailing):
        self.out(trailing)

    def continuation(self, text):
        self.out(text)

serialiser = MoinTableSerialiser

# vim: tabstop=4 expandtab shiftwidth=4
